==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/HostSubnetListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HostSubnetListBuilder extends HostSubnetListFluentImpl<HostSubnetListBuilder> implements VisitableBuilder<HostSubnetList,HostSubnetListBuilder>{
  public HostSubnetListBuilder() {
    this(false);
  }
  public HostSubnetListBuilder(Boolean validationEnabled) {
    this(new HostSubnetList(), validationEnabled);
  }
  public HostSubnetListBuilder(HostSubnetListFluent<?> fluent) {
    this(fluent, false);
  }
  public HostSubnetListBuilder(HostSubnetListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HostSubnetList(), validationEnabled);
  }
  public HostSubnetListBuilder(HostSubnetListFluent<?> fluent,HostSubnetList instance) {
    this(fluent, instance, false);
  }
  public HostSubnetListBuilder(HostSubnetListFluent<?> fluent,HostSubnetList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HostSubnetListBuilder(HostSubnetList instance) {
    this(instance,false);
  }
  public HostSubnetListBuilder(HostSubnetList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HostSubnetListFluent<?> fluent;
  Boolean validationEnabled;
  public HostSubnetList build() {
    HostSubnetList buildable = new HostSubnetList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.1-sources.jar: io/fabric8/openshift/api/model/HostSubnetListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HostSubnetListBuilder extends HostSubnetListFluent<HostSubnetListBuilder> implements VisitableBuilder<HostSubnetList,HostSubnetListBuilder>{
  public HostSubnetListBuilder() {
    this(false);
  }
  public HostSubnetListBuilder(Boolean validationEnabled) {
    this(new HostSubnetList(), validationEnabled);
  }
  public HostSubnetListBuilder(HostSubnetListFluent<?> fluent) {
    this(fluent, false);
  }
  public HostSubnetListBuilder(HostSubnetListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HostSubnetList(), validationEnabled);
  }
  public HostSubnetListBuilder(HostSubnetListFluent<?> fluent,HostSubnetList instance) {
    this(fluent, instance, false);
  }
  public HostSubnetListBuilder(HostSubnetListFluent<?> fluent,HostSubnetList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HostSubnetList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HostSubnetListBuilder(HostSubnetList instance) {
    this(instance,false);
  }
  public HostSubnetListBuilder(HostSubnetList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HostSubnetList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HostSubnetListFluent<?> fluent;
  Boolean validationEnabled;
  public HostSubnetList build() {
    HostSubnetList buildable = new HostSubnetList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
